/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef LEDPARAMCONTROLLER_H
#define LEDPARAMCONTROLLER_H

#include <Controller.h>
#include "drivers/stereo_elec/StereoElecDriver.h"
#include "DAQParamController.h"

namespace stereo_daq {


/*!
 * \class LEDParamController
 */

class LEDParamController: public ExperimentController,
		public Select,
		public Set{

public:

	//! Type of controller
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 *
	 * It is the default constructor called by the creator class ExperimentControllerCreator.
	 *
	 * \param[in] name the name of the controller
	 */
	LEDParamController(const std::string& name);

	/*!
	 * \brief Copy constructor
	 *
	 * \param[in] controller the controller to copy
	 */
	LEDParamController(const LEDParamController& controller);

	/*!
	 * \brief Destructor
	 */
	virtual ~LEDParamController();

	/*!
	 * \brief Method called before changing the property value
	 *
	 * This method is called after setting configuration during the creation of controller.
	 */
	virtual void postConfiguration();

	/*!
	 * Properties
	 */



protected:


	DriverPtr<stereo_elec::StereoElecDriver> m_Driver; //! The driver linked to the controller

	/*!
	* \brief select command
	*/
	virtual void select();

	/*!
	* \brief select command
	*/
	virtual void set();

private:

	/*
	 * local values
	 */
	bool m_StartActivated; //! Started activated flag



	/*!
	 * \brief update the progression property from driver one
	 */
	void updateProgression();


};
}
#endif // LEDPARAMCONTROLLER_H
