/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "RealStereoElecDriver.h"
#include "StereoElecDriver.h"
#include "StereoElecDef.h"

#include <iostream>

using namespace std;

namespace stereo_elec {

/*
 * Constructor
 */
RealStereoElecDriver::RealStereoElecDriver(StereoElecDriver* owner) :
		StereoElecState(owner) {

}

/*
 * Destructor
 */
RealStereoElecDriver::~RealStereoElecDriver() {

	// Empty
}

/*
 * init
 */
void RealStereoElecDriver::init() {

}

/*
 * clear
 */
void RealStereoElecDriver::clear() {

}

/*
 * writeParam
 */
void RealStereoElecDriver::writeParam() {
}

/*
 * readInfos
 */
void RealStereoElecDriver::readInfos() {
}
/*
 * start
 */
void RealStereoElecDriver::start() {

	m_TimeCounter.clear();
	//m_Status = COUNT_ON;
}

/*
 * stop
 */
void RealStereoElecDriver::stop() {
}

/*
 * read
 */
void RealStereoElecDriver::read() {
	uint32 size = (uint32) owner()->dataSize();
	int32* data = owner()->data();
	/*
	 * Calculate the detector sum
	 */
	float64 sum = 0;
	for (uint32 i = 0; i < size; i++) {
		// Limit value for avoid negative value

		// Calculate the sum
		sum += (float64) data[i];
	}

	// If data changed send event
	owner()->sum.update(sum);
	owner()->data.sendEvent();
}

/*
 * synchroniseRead
 */
void RealStereoElecDriver::synchroniseRead() {
	read();
	owner()->m_SynchroniseReadTerminated = true;
}

/*
 * readStatus
 */
void RealStereoElecDriver::readStatus() {
	if (owner()->startActivated() == true) {
		bool finished = false;
		int32 mode = owner()->mode();

		float64 actual = m_TimeCounter.getTime();
		owner()->time.update(actual);

		if (mode == acquisition::GateCommon::TIME_MODE) {
			float64 target = owner()->time.setpoint();
			if (actual >= target) {
				finished = true;
				actual = target;
			}

		} else if (mode == acquisition::GateCommon::COUNTER1_MODE) {

		}

		if (finished) {
			//m_Status = COUNT_END;
			//owner()->status.update(m_Status);
			//owner()->computeGateStatus(m_Status);
			//owner()->computeAcquisitionStatus(0);
			owner()->computeDetectorStatus(0);
			owner()->startActivated = false;
			owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
		} else {
			//owner()->status.update(m_Status);
			//owner()->computeGateStatus(m_Status);
			//owner()->computeAcquisitionStatus(0);
			owner()->computeDetectorStatus(0);
			owner()->calculateProgression();
		}
	} else {
		if (owner()->m_SynchroniseReadActivated == true) {
			if (owner()->m_SynchroniseReadTerminated == true) {
				owner()->m_SynchroniseReadActivated = false;
				owner()->m_SynchroniseReadTerminated = false;
				owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
			}
		} else {
			owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
		}
		//m_Status = COUNT_END;
		//owner()->status.update(m_Status);
		//owner()->computeGateStatus(m_Status);
		//owner()->computeAcquisitionStatus(0);
		owner()->computeDetectorStatus(0);
	}
}

}
