/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef REALSTEREOELECDRIVER_H
#define REALSTEREOELECDRIVER_H

#include "StereoElecState.h"
#include "Utilities/Counter.h"
#include "TstereoDaqLib.h"

namespace stereo_elec {

class StereoElecDriver;

/**
 * Real implementation
 */
class RealStereoElecDriver: public StereoElecState {

public:

	/**
	 * Constructor.
	 *
	 * @param Link to the class which used the state
	 */
	RealStereoElecDriver(StereoElecDriver* owner);

	/**
	 * Destructor.
	 * Empty.
	 */
	virtual ~RealStereoElecDriver();

	/**
	 * Perform a init.
	 */
	virtual void init();
	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void start();
	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop();

	/*!
	 * \brief Read command implementation
	 */
	virtual void read();

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

private:
	Counter m_TimeCounter; //! Time counter
	TstereoDaqLib *daq;

};

}
#endif //REALSTEREOELECDRIVER_H
